@@ -46,7 +46,6 @@ class JobWidget(urwid.WidgetWrap):
         self.columns = OrderedDict()
         self.columns["selected"] = urwid.Text("", wrap="ellipsis")
         self.columns["job_id"] = urwid.Text("", wrap="ellipsis")
-        self.columns["array"] = urwid.Text("", wrap="ellipsis")
         self.columns["user"] = urwid.Text("", wrap="ellipsis")
         self.columns["name"] = urwid.Text("", wrap="ellipsis")
         self.columns["state"] = urwid.AttrMap(urwid.Text("", wrap="ellipsis"), None)
@@ -74,7 +73,6 @@ class JobWidget(urwid.WidgetWrap):
 
     def update_values(self, job):
         self.columns["job_id"].set_text(job.job_id)
-        self.columns["array"].set_text(job.array_str())
         self.columns["user"].set_text(job.user)
         self.columns["name"].set_text(job.name)
         self.columns["state"]._original_widget.set_text(job.state.title())
@@ -120,7 +118,6 @@ class JobQueueWidget(urwid.WidgetWrap):
     column_widths = [
         (2,),
         (10,),
-        (10,),
         ("weight", 1),
         ("weight", 2),
         (14,),
@@ -136,7 +133,6 @@ class JobQueueWidget(urwid.WidgetWrap):
         column_labels = [
             "",
             "Job ID",
-            "Job Array",
             "User",
             "Name",
             "State",
@@ -746,13 +742,13 @@ class StuiApp(object):
 
         elif message == b"connection established":
             self.fd = None  # TODO: delattr?
-            self.register_refresh()
-            self.w.cluster_connected_callback()
+        self.register_refresh()
+        self.w.cluster_connected_callback()
 
             # Return False so that the watch is removed from main loop and its read-end
             # of the pipe is closed. The write-end of the pipe will be closed on the
             # backend.
-            return False
+        return False
 
     def run(self):
         # self.loop.screen.set_terminal_properties(bright_is_bold=False)
@@ -794,14 +790,6 @@ def parse_args():
         help="Remote destination where slurm controller is running. Format: --remote {Host name defined in ssh config} or --remote {username@server}. Does _not_ prompt for password and relies on ssh-keys for authentication.",
     )
 
-    parser.add_argument(
-        "-r",
-        "--refresh-interval",
-        type=int,
-        default=1,
-        help="Refresh interval (in seconds) for fetching data from the cluster. (Default: 1s)",
-    )
-
     args = parser.parse_args()
 
     return args
